@@ -23,7 +23,8 @@ public enum FileSystemType implements Serializable {
     HDFS("HdfsFile"),
     LOCAL("LocalFile"),
     OSS("OssFile"),
-    FTP("FtpFile");
+    FTP("FtpFile"),
+    S3("S3File");
 
     private final String fileSystemPluginName;
 
