@@ -22,7 +22,7 @@ import org.apache.seatunnel.core.starter.exception.ConfigCheckException;
 
 import org.apache.seatunnel.shade.com.typesafe.config.Config;
 
-public class FlinkApiConfigChecker implements ConfigChecker<FlinkApiEnvironment> {
+public class FlinkApiConfigChecker implements ConfigChecker {
 
     @Override
     public void checkConfig(Config config) throws ConfigCheckException {
